==> guile-2.0.11-4-arm.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-lHA3y8Zqxk290mTeAhoXHC-1316	*)# 	+*$ 	,f  l-lHA3y8Zqxk290mTeAhoXHC-1321	-f  l-lHA3y8Zqxk290mTeAhoXHC-1322	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-lHA3y8Zqxk290mTeAhoXHC-1318	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 

==> guile-2.0.12-1-arm.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-WaR$MQbj5Wy$2cnoh1eht3-3457	*)# 	+*$ 	,f  l-WaR$MQbj5Wy$2cnoh1eht3-3462	-f  l-WaR$MQbj5Wy$2cnoh1eht3-3463	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-WaR$MQbj5Wy$2cnoh1eht3-3459	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 
